PALM-meteo: palmmeteo.runtime.RuntimeObj Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Protected Member Functions | List of all members
palmmeteo.runtime.RuntimeObj Class Reference

## Protected Member Functions
| _get_child (self, child_name)
| _save (self, fpath)
| _load (self, fpath)

## Detailed Description

    An object for holding runtime-related values.

    May be nested.

## Member Function Documentation

## ◆ _get_child()

palmmeteo.runtime.RuntimeObj._get_child | ( |  | self,
|  |  | child_name
| ) |  |
| protected

## ◆ _load()

palmmeteo.runtime.RuntimeObj._load | ( |  | self,
|  |  | fpath
| ) |  |
| protected

## ◆ _save()

palmmeteo.runtime.RuntimeObj._save | ( |  | self,
|  |  | fpath
| ) |  |
| protected

The documentation for this class was generated from the following file:

- palmmeteo/runtime.py